{+--------------------------------------------------------------------------+
 | Component:   TmwCustomCompoundComponent
 | Author:      Martin Waldenburg
 | Copyright    1997, all rights reserved.
 | Description: Base class for compound components, you can design visually
 |              with help of the form editor.
 | Version:     1.2
 | Status:      Freeware
 | DISCLAIMER: This is provided as is, expressly without a warranty of any kind.
 |             You use it at your own risc.
 +--------------------------------------------------------------------------+}

unit mwCuCoCo;

interface

uses
  SysUtils, WinTypes, Classes, Graphics, Controls, ExtCtrls, Buttons, Forms, 
  Messages, Menus;

type
  TmwCustomCompoundComponent = class(TPanel)
 private
    { Private declarations }
    fTextHeight: Integer;
    fMoveAble:Boolean;
    fBorderStyle:TBorderStyle;
    procedure GetTextHeight(Reader: TReader);
    procedure SetTextHeight(Writer: TWriter);
    procedure GetPixelsPerInch(Reader: TReader);
    procedure SetPixelsPerInch(Writer: TWriter);
    procedure DefineProperties(Filer: TFiler); override;
    function RunTime: Boolean;
    procedure WMNCHitTest(var NCTest: TWMNCHitTest);message WM_NCHitTest;
  protected
    { Protected declarations }
  public
    { Public declarations }
    constructor Create(Owner: TComponent); override;
    property MoveAble:Boolean read fMoveAble write fMoveAble;
  published
    { Published declarations }
    property BorderStyle:TBorderStyle read fBorderStyle;
  end;

var
  mwCustomCompoundComponent: TmwCustomCompoundComponent;

implementation

{$R *.DFM}

{ This component has two fake properties, TextHeight and PixelsPerInch.
  The form editor stores these properties in the .DFM file, TextHeight
  always and PixelsPerInch in some cases.
  This will only be a problem if you use the form editor as a component editor.
  However what is stored in the .DFM file must be handled.
  You may use the the TextHeight Property to store any integer value. }
procedure TmwCustomCompoundComponent.DefineProperties(Filer: TFiler);
begin
  inherited DefineProperties(Filer);
  Filer.DefineProperty('TextHeight', GetTextHeight, SetTextHeight, True);
  Filer.DefineProperty('PixelsPerInch', GetPixelsPerInch, SetPixelsPerInch, False);
end;

{ Create a CustomCompoundComponent and set some default properties. }
constructor TmwCustomCompoundComponent.Create(Owner: TComponent);
var
  FormBorder, FormCaption, FormFrame: Integer;
begin
  inherited Create(Owner);
  ReadComponentRes(Self.ClassName, Self);
  fBorderStyle:= bsNone;
  FormBorder:= GetSystemMetrics(SM_CXBORDER);
  FormCaption:= GetSystemMetrics(SM_CYCAPTION);
  FormFrame:= GetSystemMetrics(SM_CXFIXEDFRAME); { use SM_CXFRAME for Windows 3.1 }
  Align := alNone;
  BevelOuter := bvRaised;
  Caption := '';
  { Consider this is a panel. To prevent your user from dropping
    any other controls on it, you must set the ControlStyle accordingly. }
  ControlStyle := ControlStyle - [csAcceptsControls, csSetCaption];
  Height:= Height - FormCaption - FormFrame *2 - FormBorder *2;
  Width:= Width - FormFrame *2 - FormBorder *2;
end;

procedure TmwCustomCompoundComponent.GetTextHeight(Reader: TReader);
begin
  FTextHeight:= Reader.ReadInteger;
end;  { GetTextHeight }

procedure TmwCustomCompoundComponent.SetTextHeight(Writer: TWriter);
begin
  Writer.WriteInteger(fTextHeight);
end;  { SetTextHeight }

procedure TmwCustomCompoundComponent.GetPixelsPerInch(Reader: TReader);
begin
  { Ignore it } Reader.ReadInteger;
end;  { GetPixelsPerInch }

procedure TmwCustomCompoundComponent.SetPixelsPerInch(Writer: TWriter);
begin
  Writer.WriteInteger(0);
end;  { SetPixelsPerInch }

function TmwCustomCompoundComponent.RunTime: Boolean;
begin
  RunTime := not (csDesigning in ComponentState);
end;		{ RunTime }

procedure TmwCustomCompoundComponent.WMNCHitTest(var NCTest: TWMNCHitTest);
begin
  inherited;
  if Runtime and MoveAble then NCTest.Result:= htCaption;
end;  { WMNCHitTest }


end.
